@@ -9,6 +9,7 @@ import time
 import deimos.cleanup
 import deimos.config
 import deimos.containerizer
+import deimos.containerizer.docker
 from deimos.err import Err
 import deimos.flock
 from deimos.logger import log
@@ -18,7 +19,8 @@ import deimos.usage
 
 def cli(argv=None):
     deimos.sig.install(lambda _: None)
-    if argv is None: argv = sys.argv
+    if argv is None:
+        argv = sys.argv
     sub = argv[1] if len(argv) > 1 else None
 
     if sub in ["-h", "--help", "help"]:
@@ -39,7 +41,7 @@ def cli(argv=None):
 
     if sub == "state":
         cleanup = deimos.cleanup.Cleanup(conf.state.root)
-        t, rm   = time.time(), False
+        t, rm = time.time(), False
         for arg in argv[2:]:
             if arg == "--rm":
                 rm = True
@@ -59,7 +61,7 @@ def cli(argv=None):
         return 1
 
     deimos.docker.options = conf.docker.argv()
-    containerizer = deimos.containerizer.Docker(
+    containerizer = deimos.containerizer.docker.Docker(
         container_settings=conf.containers,
         optimistic_unpack=conf.uris.unpack,
         state_root=conf.state.root
@@ -67,9 +69,11 @@ def cli(argv=None):
 
     deimos.usage.report()
     try:
-        result = containerizer(*argv[1:])
+        result = deimos.containerizer.stdio(containerizer, *argv[1:])
         deimos.usage.report()
         if result is not None:
+            if isinstance(result, bool):
+                return 0 if result else 1
             if isinstance(result, int):
                 return result
             if isinstance(result, str):
@@ -88,6 +92,7 @@ def cli(argv=None):
         return 8
     return 0
 
+
 def format_help():
     return """
  USAGE: deimos launch  (--no-fork)?
@@ -144,4 +149,3 @@ def format_help():
 
 if __name__ == "__main__":
     sys.exit(cli(sys.argv))
-
