@@ -14,56 +14,66 @@ from deimos.timestamp import iso
 
 
 class State(_Struct):
+
     def __init__(self, root, docker_id=None, mesos_id=None, executor_id=None):
         _Struct.__init__(self, root=os.path.abspath(root),
                                docker_id=docker_id,
                                mesos_id=mesos_id,
                                executor_id=executor_id,
                                timestamp=None)
+
     def resolve(self, *args, **kwargs):
         if self.mesos_id is not None:
             return self._mesos(*args, **kwargs)
         else:
             return self._docker(*args, **kwargs)
+
     def mesos_container_id(self):
         if self.mesos_id is None:
             self.mesos_id = self._readf("mesos-container-id")
         return self.mesos_id
+
     def eid(self):
         if self.executor_id is None:
             self.executor_id = self._readf("eid")
         return self.executor_id
+
     def sandbox_symlink(self, value=None):
         p = self.resolve("fs")
         if value is not None:
             link(value, p)
         return p
+
     def pid(self, value=None):
         if value is not None:
             self._writef("pid", str(value))
         data = self._readf("pid")
         if data is not None:
             return int(data)
+
     def cid(self, refresh=False):
         if self.docker_id is None or refresh:
             self.docker_id = self._readf("cid")
         return self.docker_id
+
     def t(self):
         if self.timestamp is None:
             self.timestamp = self._readf("t")
         return self.timestamp
+
     def await_cid(self, seconds=60):
-        base   = 0.05
-        start  = time.time()
-        steps  = [ 1.0, 1.25, 1.6, 2.0, 2.5, 3.2, 4.0, 5.0, 6.4, 8.0 ]
-        scales = ( 10.0 ** n for n in itertools.count() )
-        scaled = ( [scale * step for step in steps] for scale in scales )
+        base = 0.05
+        start = time.time()
+        steps = [1.0, 1.25, 1.6, 2.0, 2.5, 3.2, 4.0, 5.0, 6.4, 8.0]
+        scales = (10.0 ** n for n in itertools.count())
+        scaled = ([scale * step for step in steps] for scale in scales)
         sleeps = itertools.chain.from_iterable(scaled)
         log.info("Awaiting CID file: %s", self.resolve("cid"))
         while self.cid(refresh=True) in [None, ""]:
             time.sleep(next(sleeps))
             if time.time() - start >= seconds:
                 raise CIDTimeout("No CID file after %ds" % seconds)
+
     def await_launch(self):
         lk_l = self.lock("launch", LOCK_SH)
         self.ids(3)
@@ -72,8 +82,9 @@ class State(_Struct):
             self.await_cid()
             lk_l = self.lock("launch", LOCK_SH)
         return lk_l
+
     def lock(self, name, flags, seconds=60):
-        fmt_time  = "indefinite" if seconds is None else "%ds" % seconds
+        fmt_time = "indefinite" if seconds is None else "%ds" % seconds
         fmt_flags = deimos.flock.format_lock_flags(flags)
         flags, seconds = deimos.flock.nb_seconds(flags, seconds)
         log.info("request // %s %s (%s)", name, fmt_flags, fmt_time)
@@ -88,12 +99,14 @@ class State(_Struct):
             lk.handle.write(iso() + "\n")
         log.info("success // %s %s (%s)", name, fmt_flags, fmt_time)
         return lk
+
     def exit(self, value=None):
         if value is not None:
             self._writef("exit", str(value))
         data = self._readf("exit")
         if data is not None:
             return deimos.docker.read_wait_code(data)
+
     def push(self):
         self._mkdir()
         properties = [("cid", self.docker_id),
@@ -106,6 +119,7 @@ class State(_Struct):
         if self.cid() is not None:
             docker = os.path.join(self.root, "docker", self.cid())
             link("../mesos/" + self.mesos_id, docker)
+
     def set_start_time(self):
         if self.t() is not None:
             return
@@ -124,18 +138,22 @@ class State(_Struct):
                     raise
                 time.sleep(random.uniform(0.005, 0.025))
                 t = iso()
+
     def _mkdir(self):
         create(self._mesos())
+
     def _readf(self, path):
         f = self.resolve(path)
         if os.path.exists(f):
             with open(f) as h:
                 return h.read().strip()
+
     def _writef(self, path, value):
         f = self.resolve(path)
         with open(f, "w+") as h:
             h.write(value + "\n")
             h.flush()
+
     def _docker(self, path=None, mkdir=False):
         if path is None:
             p = os.path.join(self.root, "docker", self.docker_id)
@@ -149,6 +167,7 @@ class State(_Struct):
                 raise Err("Bad Docker symlink state")
             create(os.path.dirname(p))
         return p
+
     def _mesos(self, path=None, mkdir=False):
         if path is None:
             p = os.path.join(self.root, "mesos", self.mesos_id)
@@ -158,6 +177,7 @@ class State(_Struct):
         if mkdir:
             create(os.path.dirname(p))
         return p
+
     def ids(self, height=2):
         log = deimos.logger.logger(height)
         if self.eid() is not None:
@@ -166,6 +186,7 @@ class State(_Struct):
             log.info("mesos  = %s", self.mesos_container_id())
         if self.cid() is not None:
             log.info("docker = %s", self.cid())
+
     def exists(self):
         path = None
         if self.mesos_id is not None:
@@ -176,17 +197,22 @@ class State(_Struct):
             return os.path.exists(path)
         return False
 
-class CIDTimeout(Err): pass
+
+class CIDTimeout(Err):
+    pass
+
 
 def create(path):
     if not os.path.exists(path):
         os.makedirs(path)
 
+
 def link(source, target):
     if not os.path.exists(target):
         create(os.path.dirname(target))
         os.symlink(source, target)
 
+
 def state(directory):
     mesos = os.path.join(directory, "mesos-container-id")
     if os.path.exists(mesos):
@@ -194,4 +220,3 @@ def state(directory):
             mesos_id = h.read().strip()
         root = os.path.dirname(os.path.dirname(os.path.realpath(directory)))
         return State(root=root, mesos_id=mesos_id)
-
